@@ -110,8 +110,8 @@ class IQOption:
             done, id = self.iq.buy_digital_spot(symbol, contract, "put", int(timeframe))
         
         if not done:
-            print('Error put')
-            print(done, id)
+            logging.error(id)
+            raise Exception(id)
         
         return id   
 
@@ -124,8 +124,8 @@ class IQOption:
             done, id = self.iq.buy_digital_spot(symbol, contract, direction, int(timeframe))
         
         if not done:
-            print('Error put')
-            print(done, id)
+            logging.error(id)
+            raise Exception(id)
         
         return done, id   
     
@@ -157,8 +157,12 @@ class IQOption:
                 }
                 isOpen.append(result)
 
-            
-        return pd.DataFrame(isOpen)
+    
+        markets = pd.DataFrame(isOpen)
+        keys = list(OP_code.ACTIVES.keys())
+        mask = markets['Asset'].isin(keys)
+        markets = markets[mask]
+        return markets
 
     def payout(self, symbol, turbo=None):
         if turbo:
